.. Backslash documentation master file, created by
   sphinx-quickstart on Tue May  9 17:24:30 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Backslash Python SDK
====================

Overview
--------

This library is intended to act as the official Python client for the `Backslash <https://getslash.github.io/backslash>`_ test reporting service.

Contents:

.. toctree::
   :maxdepth: 2

   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

